<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

include_once '../../config/database.php';
include_once '../../class/withdrawal.php';
include_once '../../class/passbook.php';
include_once '../constant/validateApiData.php';

$database = new Database();
$db = $database->getConnection();

$withdrawalOBJ = new Withdrawal($db);
$passbookOBJ = new Passbook($db);

include_once '../constant/secure_token.php';

$apiData = json_decode(file_get_contents("php://input"));

$status = "false";
$data = "Invalid API Call";
$code = "0";

if (
    apiValidateString($apiData->user_id, "user_id") &&
    apiValidateString($apiData->points, "points") &&
    apiValidateString($apiData->method, "method")
) {
    $withdrawalOBJ->user_id = $apiData->user_id;
    $withdrawalOBJ->points = $apiData->points;
    $withdrawalOBJ->status = 0;                         // (pending(0), approved(1), declined(2), failed(3))
    $withdrawalOBJ->admin_id = 0;
    $withdrawalOBJ->method = $apiData->method;          // bank / phone(gpay, phonepe, paytm)
    $withdrawalOBJ->createdOn = date('Y-m-d H:i:s');

    //Passbook Obj Items
    $passbookOBJ->user_id = $apiData->user_id;

    //if wallet balance is greater than points otherwise throw an error
    $passbookSTMT = $passbookOBJ->getWalletBalance();
    if ($passbookSTMT->rowCount() > 0) {
        $dataRow = $passbookSTMT->fetch(PDO::FETCH_ASSOC);
        $cur_balance = intval($dataRow["balance"]);
    } else {
        $cur_balance = 0;
    }

    $current_datetime = date_create();

    if ($cur_balance >= intval($withdrawalOBJ->points) && $cur_balance != 0) {
        //if method exist then method id otherwise throw an error
        $method_id = $withdrawalOBJ->checkMethodExist();
        if ($method_id > 0) {
            //method available 
            $withdrawalOBJ->method_id = $method_id;
            if (((int)$current_datetime->format('H')) >= 10 && ((int)$current_datetime->format('H')) < 15) {
                ///Check Withdrawal Request Exist or not on today
                if ($withdrawalOBJ->checkWithdrawalRequest()) {
                    $status = "true";
                    $data = "Withdrawal Request Exist! Try Tomorrow!";
                    $code = "5006";
                } else {
                    //Send Withdrawal Reuqest
                    if ($withdrawalOBJ->sendWithdrawalRequest()) {
                        $status = "true";
                        $data = "Withdrawal Request Sent Successfully!";
                        $code = "5001";
                    } else {
                        $status = "true";
                        $data = "Amount Deducted From Wallet But Request Not Sent, Please Wait!";
                        $code = "5005";
                    }
                }
            } else {
                $status = "true";
                $data = "Withdrawal Request Timing 10 AM To 3 PM";
                $code = "5002";
            }
        } else {
            //no method available 5003
            $status = "true";
            $data = "Withdrawal Method Not Available";
            $code = "5003";
        }
    } else {
        //current balance is less than withdrawal points request
        $status = "true";
        $data = "Current Balance is Less Than Requested Amount!";
        $code = "5004";
    }

    echo json_encode(array("data" => $data, "status" => $status, "code" => $code));
} else {
    die;
}
