<?php
error_reporting(0);
class Devices
{
    // Connection
    private $conn;
    // Table
    private $db_table = "devices";
    // Columns
    public $id;
    public $userId;
    public $token;
    public $location;
    public $lastLogin;
    public $createdOn;
    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    // CREATE
    public function createDevice()
    {
        $sqlQuery = "INSERT INTO
                        " . $this->db_table . "
                    SET
                        userId = :userId, 
                        token = :token,
                        lastLogin = :lastLogin, 
                        createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->token = htmlspecialchars(strip_tags($this->token));
        $this->lastLogin = htmlspecialchars(strip_tags($this->lastLogin));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));
        // bind data
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":token", $this->token);
        $stmt->bindParam(":lastLogin", $this->lastLogin);
        $stmt->bindParam(":createdOn", $this->createdOn);
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    public function isTokenExist()
    {
        $sqlQuery = "SELECT
                        id
                      FROM
                        " . $this->db_table . "
                    WHERE 
                       userId = :userId AND token = :token";

        $stmt = $this->conn->prepare($sqlQuery);
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":token", $this->token);
        if ($stmt->execute()) {
            if ($stmt->rowCount() > 0) {
                return true;
            }
            return false;
        }
        return false;
    }

    // UPDATE
    public function updateDevice()
    {
        $sqlQuery = "UPDATE
                        " . $this->db_table . "
                    SET 
                        location = :location, 
                        lastLogin = :lastLogin
                    WHERE 
                        token = :token";

        $stmt = $this->conn->prepare($sqlQuery);

        $this->location = htmlspecialchars(strip_tags($this->location));
        $this->lastLogin = htmlspecialchars(strip_tags($this->lastLogin));
        $this->token = htmlspecialchars(strip_tags($this->token));
        // bind data
        $stmt->bindParam(":location", $this->location);
        $stmt->bindParam(":lastLogin", $this->lastLogin);
        $stmt->bindParam(":token", $this->token);
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    // DELETE
    function deleteDevice()
    {
        $sqlQuery = "DELETE FROM " . $this->db_table . " WHERE userId = :userId AND token = :token";
        $stmt = $this->conn->prepare($sqlQuery);
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":token", $this->token);
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }
}
