<?php
error_reporting(0);
class MarketBid
{
    // Connection
    private $conn;

    // Table
    private $db_table = "matka_market_bid_history";

    // Columns
    public $id;
    public $marketId;
    public $gameId;
    public $userId;
    public $winning_status;
    public $session;
    public $bid_details;
    public $bid_digit;
    public $bid_point;
    public $win_point;
    public $createdOn;

    public $lastEntryId = 0;
    private $entriesLimit = 10;

    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    private function getPanaGameId($num)
    {
        $numArr = str_split($num);
        if (in_array("0", $numArr)) {
            foreach ($numArr as $key => $value) {
                if ($value == 0) {
                    $numArr[$key] = 10;
                }
            }
        }
        if ($numArr[0] < $numArr[1] and $numArr[1] < $numArr[2]) {
            return 3;   // Single Pana Game ID
        } else if ((($numArr[0] == $numArr[1] && $numArr[1] != $numArr[2]) || ($numArr[0] != $numArr[1] && $numArr[1] == $numArr[2])) && ($numArr[1] <= $numArr[2] && $numArr[0] < $numArr[2])) {
            return 4;    // Double Pana Game ID
        } else if ($numArr[0] == $numArr[1] and $numArr[1] == $numArr[2]) {
            return 5;    // Triple Pana Game ID
        } else {
            return 0;
        }
    }

    //Submit Bid On Market
    public function addMarketBid()
    {
        $get_win_points_query = "SELECT win_point FROM market_games WHERE id = :game_id";
        $game_stmt = $this->conn->prepare($get_win_points_query);
        $this->gameId = htmlspecialchars(strip_tags($this->gameId));
        $game_stmt->bindParam(":game_id", $this->gameId);
        $game_stmt->execute();
        $game_row = $game_stmt->fetch(PDO::FETCH_ASSOC);

        $sqlQuery = "INSERT INTO
                            " . $this->db_table . "
                        SET
                            marketId = :marketId, 
                            gameId = :gameId,
                            userId = :userId,
                            winning_status = 'pending',
                            session = :session,
                            bid_digit = :bid_digit,
                            bid_point = :bid_point,
                            win_point = :win_point,
                            createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->marketId = htmlspecialchars(strip_tags($this->marketId));
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->session = htmlspecialchars(strip_tags($this->session));
        // $this->bid_digit = htmlspecialchars(strip_tags($this->bid_digit));
        $this->bid_point = htmlspecialchars(strip_tags($this->bid_point));
        $this->win_point = $this->bid_point * $game_row["win_point"];
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));

        // bind data
        $stmt->bindParam(":marketId", $this->marketId);
        $stmt->bindParam(":gameId", $this->gameId);
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":session", $this->session);
        $stmt->bindParam(":bid_digit", $this->bid_digit);
        $stmt->bindParam(":bid_point", $this->bid_point);
        $stmt->bindParam(":win_point", $this->win_point);
        $stmt->bindParam(":createdOn", $this->createdOn);
        if ($stmt->execute()) {
            return true;
        } else {
            return false;
        }
    }

    public function addMultipleMarketBids()
    {
        // One Market Multiple Bids
        // marketId, gameId, userId, winning_status, session, created_on -> Same
        // Variable Data -> bid_digit, bid_point, win_point
        // Array for Bid Details

        // sanitize
        $this->marketId = htmlspecialchars(strip_tags($this->marketId));
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->session = htmlspecialchars(strip_tags($this->session));
        $this->bid_point = htmlspecialchars(strip_tags($this->bid_point));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));


        $sqlQuery = "INSERT INTO
                            " . $this->db_table . "
                            (marketId, gameId, userId, winning_status, session, bid_digit, bid_point, win_point, createdOn) VALUES
                        ";
        // Making Query For Multiple Insert
        foreach ($this->bid_details as $bid_digit) {
            // marketId, gameId, userId, winning_status, session, bid_digit, bid_point, win_point, createdOn
            $get_win_points_query = "SELECT win_point FROM market_games WHERE id = :game_id";
            $game_stmt = $this->conn->prepare($get_win_points_query);
            $this->gameId = htmlspecialchars(strip_tags($this->gameId));
            if ($this->gameId == 9 || $this->gameId == 10) {
                $game_stmt->bindParam(":game_id", $this->getPanaGameId($bid_digit));
            } else {
                $game_stmt->bindParam(":game_id", $this->gameId);
            }
            $game_stmt->execute();
            $game_row = $game_stmt->fetch(PDO::FETCH_ASSOC);
            $game_win_point = $game_row["win_point"];
            $this->win_point = $this->bid_point * $game_win_point;

            $sqlQuery .= "($this->marketId, $this->gameId, $this->userId, 'pending', '$this->session', '$bid_digit', $this->bid_point, $this->win_point, '$this->createdOn')";
            if ($bid_digit != end($this->bid_details)) {
                $sqlQuery .= ",
                ";
            }
        }
        // print($sqlQuery);
        $stmt = $this->conn->prepare($sqlQuery);
        if ($stmt->execute()) {
            return true;
        } else {
            return false;
        }
    }

    public function getMarketBidHistory()
    {
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        userId = :userId && id " . $querySymbol . " :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT " . $this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        //bind data
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        $stmt->execute();
        if ($stmt->rowCount() > 0) {
            $bid_arr = $stmt->fetchAll(PDO::FETCH_ASSOC);
            foreach ($bid_arr as $bidNo => $bidRow) {
                $market_info_query = "SELECT id, market_name, open_time, close_time, schedule FROM matka_market WHERE id = :marketId";
                $market_stmt = $this->conn->prepare($market_info_query);
                $market_stmt->bindParam(":marketId", $bidRow["marketId"]);
                $market_stmt->execute();
                $market_arr = $market_stmt->fetch(PDO::FETCH_ASSOC);
                $bid_arr[$bidNo]["market"] = $market_arr;

                $game_info_query = "SELECT id, gameCode, gameName, win_point FROM market_games WHERE id = :gameId";
                $game_stmt = $this->conn->prepare($game_info_query);
                $game_stmt->bindParam(":gameId", $bidRow["gameId"]);
                $game_stmt->execute();
                $game_arr = $game_stmt->fetch(PDO::FETCH_ASSOC);
                $bid_arr[$bidNo]["game"] = $game_arr;
            }
            return $bid_arr;
        } else {
            return [];
        }
    }

    public function getSpecificMarketBidHistory()
    {
        $dateQuerySymbol = $this->createdOn == "all" ? "<" : "=";

        if ($this->createdOn == "all") {
            $historyDate = date_create();
            date_add($historyDate, date_interval_create_from_date_string('1 days'));
            $historyDate = strval(date_format($historyDate, 'Y-m-d H:i:s'));
        } else {
            $historyDate = date_create($this->createdOn);
            $historyDate = strval(date_format($historyDate, 'Y-m-d H:i:s'));
        }

        $statusQuerySymbol = $this->winning_status == "all" ? "!=" : "=";
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        userId = :userId && marketId = :mid && Date(createdOn) " . $dateQuerySymbol . " :historyDate && winning_status " . $statusQuerySymbol . " :winning_status && id " . $querySymbol . " :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT " . $this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->marketId = htmlspecialchars(strip_tags($this->marketId));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        $this->winning_status = htmlspecialchars(strip_tags($this->winning_status));
        //bind data
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":mid", $this->marketId);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        $stmt->bindParam(":historyDate", $historyDate);
        $stmt->bindParam(":winning_status", $this->winning_status);
        $stmt->execute();
        if ($stmt->rowCount() > 0) {
            $bid_arr = $stmt->fetchAll(PDO::FETCH_ASSOC);
            foreach ($bid_arr as $bidNo => $bidRow) {
                $market_info_query = "SELECT id, market_name, open_time, close_time, schedule FROM matka_market WHERE id = :marketId";
                $market_stmt = $this->conn->prepare($market_info_query);
                $market_stmt->bindParam(":marketId", $bidRow["marketId"]);
                $market_stmt->execute();
                $market_arr = $market_stmt->fetch(PDO::FETCH_ASSOC);
                $bid_arr[$bidNo]["market"] = $market_arr;

                $game_info_query = "SELECT id, gameCode, gameName, win_point FROM market_games WHERE id = :gameId";
                $game_stmt = $this->conn->prepare($game_info_query);
                $game_stmt->bindParam(":gameId", $bidRow["gameId"]);
                $game_stmt->execute();
                $game_arr = $game_stmt->fetch(PDO::FETCH_ASSOC);
                $bid_arr[$bidNo]["game"] = $game_arr;
            }
            return $bid_arr;
        } else {
            return [];
        }
    }
}
