<?php
error_reporting(0);
class Passbook
{
    // Connection
    private $conn;
    // Table
    private $db_table = "passbook";
    // Columns
    public $id;
    public $user_id;
    public $admin_id;
    public $txn_id;
    public $type;
    public $status;
    public $debit;
    public $credit;
    public $balance;
    public $description;
    public $createdOn;

    public $lastEntryId = 0;
    private $entriesLimit = 10;
    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    public function getWalletBalance()
    {
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        user_id = :user_id && status != 0 ORDER BY id DESC, createdOn DESC LIMIT 0,1";
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        //bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->execute();
        return $stmt;
    }

    //Add Wallet Points
    public function debitWalletPoints()
    {
        $sqlQuery = "INSERT INTO
                        " . $this->db_table . "
                    SET
                        user_id = :user_id,
                        txn_id = :txn_id,
                        type = :type,
                        status = :status,
                        debit = :debit,
                        balance = :balance,
                        description = :description,
                        createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        $this->txn_id = htmlspecialchars(strip_tags($this->txn_id));
        $this->type = htmlspecialchars(strip_tags($this->type));
        $this->status = htmlspecialchars(strip_tags($this->status));
        $this->debit = htmlspecialchars(strip_tags($this->debit));
        $this->balance = htmlspecialchars(strip_tags($this->balance));
        // $this->description = htmlspecialchars(strip_tags($this->description));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));

        // bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":txn_id", $this->txn_id);
        $stmt->bindParam(":type", $this->type);
        $stmt->bindParam(":status", $this->status);
        $stmt->bindParam(":debit", $this->debit);
        $stmt->bindParam(":balance", $this->balance);
        $stmt->bindParam(":description", $this->description);
        $stmt->bindParam(":createdOn", $this->createdOn);

        if ($stmt->execute()) {
            // try {
            //     $this->id = $this->conn->lastInsertId();
            // } catch (Exception $e) {
            //     print_r($e);
            // }
            return true;
        }
        return false;
    }

    //Deduct Wallet Points
    public function creditWalletPoints()
    {
        $sqlQuery = "INSERT INTO
                        " . $this->db_table . "
                    SET
                        user_id = :user_id,
                        txn_id = :txn_id,
                        type = :type,
                        status = :status,
                        credit = :credit,
                        balance = :balance,
                        description = :description,
                        createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        $this->txn_id = htmlspecialchars(strip_tags($this->txn_id));
        $this->type = htmlspecialchars(strip_tags($this->type));
        $this->status = htmlspecialchars(strip_tags($this->status));
        $this->credit = htmlspecialchars(strip_tags($this->credit));
        $this->balance = htmlspecialchars(strip_tags($this->balance));
        // $this->description = htmlspecialchars(strip_tags($this->description));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));

        // bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":txn_id", $this->txn_id);
        $stmt->bindParam(":type", $this->type);
        $stmt->bindParam(":status", $this->status);
        $stmt->bindParam(":credit", $this->credit);
        $stmt->bindParam(":balance", $this->balance);
        $stmt->bindParam(":description", $this->description);
        $stmt->bindParam(":createdOn", $this->createdOn);

        if ($stmt->execute()) {
            // try {
            //     $this->id = $this->conn->lastInsertId();
            // } catch (Exception $e) {
            //     print_r($e);
            // }
            return true;
        }
        return false;
    }

    public function getPassbookHistory()
    {
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        user_id = :user_id && id " . $querySymbol . " :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT " . $this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        //bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        $stmt->execute();
        return $stmt;
    }
}
