<?php
error_reporting(0);
class StarlineBid
{
    // Connection
    private $conn;

    // Table
    private $db_table = "starline_bid_history";

    // Columns
    public $id;
    public $starlineId;
    public $gameId;
    public $userId;
    public $winning_status;
    public $bid_digit;
    public $bid_point;
    public $win_point;
    public $createdOn;

    public $lastEntryId = 0;
    private $entriesLimit = 10;

    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    //Submit Bid On Market
    public function addStarlineBid()
    {
        $get_win_points_query = "SELECT win_point FROM starline_games WHERE id = :game_id";
        $game_stmt = $this->conn->prepare($get_win_points_query);
        $this->gameId = htmlspecialchars(strip_tags($this->gameId));
        $game_stmt->bindParam(":game_id", $this->gameId);
        $game_stmt->execute();
        $game_row = $game_stmt->fetch(PDO::FETCH_ASSOC);

        $sqlQuery = "INSERT INTO
                            " . $this->db_table . "
                        SET
                        starlineId = :starlineId, 
                        gameId = :gameId,
                        userId = :userId,
                        winning_status = 'pending',
                        bid_digit = :bid_digit,
                        bid_point = :bid_point,
                        win_point = :win_point,
                        createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->starlineId = htmlspecialchars(strip_tags($this->starlineId));
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        // $this->bid_digit = htmlspecialchars(strip_tags($this->bid_digit));
        $this->bid_point = htmlspecialchars(strip_tags($this->bid_point));
        $this->win_point = $this->bid_point * $game_row["win_point"];
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));

        // bind data
        $stmt->bindParam(":starlineId", $this->starlineId);
        $stmt->bindParam(":gameId", $this->gameId);
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":bid_digit", $this->bid_digit);
        $stmt->bindParam(":bid_point", $this->bid_point);
        $stmt->bindParam(":win_point", $this->win_point);
        $stmt->bindParam(":createdOn", $this->createdOn);
        try {
            if ($stmt->execute()) {
                return true;
            } else {
                return false;
            }
        } catch (Exception $e) {
            return false;
            // print_r($e);
        }
    }

    //Get All Starline Bid History
    public function getStarlineBidHistory()
    {
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        userId = :userId && id " . $querySymbol . " :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT " . $this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        //bind data
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        try {
            if ($stmt->execute()) {
                if ($stmt->rowCount() > 0) {
                    $bid_arr = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    foreach ($bid_arr as $bidNo => $bidRow) {
                        $market_info_query = "SELECT id, time, dayandnight, schedule FROM starline_market WHERE id = :starlineId";
                        $market_stmt = $this->conn->prepare($market_info_query);
                        $market_stmt->bindParam(":starlineId", $bidRow["starlineId"]);
                        $market_stmt->execute();
                        $market_arr = $market_stmt->fetch(PDO::FETCH_ASSOC);
                        $bid_arr[$bidNo]["starline"] = $market_arr;

                        $game_info_query = "SELECT id, gameCode, gameName, win_point FROM starline_games WHERE id = :gameId";
                        $game_stmt = $this->conn->prepare($game_info_query);
                        $game_stmt->bindParam(":gameId", $bidRow["gameId"]);
                        $game_stmt->execute();
                        $game_arr = $game_stmt->fetch(PDO::FETCH_ASSOC);
                        $bid_arr[$bidNo]["game"] = $game_arr;
                    }
                    return $bid_arr;
                } else {
                    return [];
                }
            } else {
                return [];
            }
        } catch (Exception $e) {
            // print_r($e);
            return [];
        }
    }

    public function getSpecificStarlineBidHistory()
    {
        $dateQuerySymbol = $this->createdOn == "all" ? "<" : "=";

        if ($this->createdOn == "all") {
            $historyDate = date_create();
            date_add($historyDate, date_interval_create_from_date_string('1 days'));
            $historyDate = strval(date_format($historyDate, 'Y-m-d H:i:s'));
        } else {
            $historyDate = date_create($this->createdOn);
            $historyDate = strval(date_format($historyDate, 'Y-m-d H:i:s'));
        }

        $statusQuerySymbol = $this->winning_status == "all" ? "!=" : "=";
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        userId = :userId && starlineId = :sid && Date(createdOn) " . $dateQuerySymbol . " :historyDate && winning_status " . $statusQuerySymbol . " :winning_status && id " . $querySymbol . " :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT " . $this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);

        //Filter Data
        $this->userId = htmlspecialchars(strip_tags($this->userId));
        $this->starlineId = htmlspecialchars(strip_tags($this->starlineId));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        $this->winning_status = htmlspecialchars(strip_tags($this->winning_status));
        //bind data
        $stmt->bindParam(":userId", $this->userId);
        $stmt->bindParam(":sid", $this->starlineId);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        $stmt->bindParam(":historyDate", $historyDate);
        $stmt->bindParam(":winning_status", $this->winning_status);
        try {
            if ($stmt->execute()) {
                if ($stmt->rowCount() > 0) {
                    $bid_arr = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    foreach ($bid_arr as $bidNo => $bidRow) {
                        $market_info_query = "SELECT id, time, dayandnight, schedule FROM starline_market WHERE id = :starlineId";
                        $market_stmt = $this->conn->prepare($market_info_query);
                        $market_stmt->bindParam(":starlineId", $bidRow["starlineId"]);
                        $market_stmt->execute();
                        $market_arr = $market_stmt->fetch(PDO::FETCH_ASSOC);
                        $bid_arr[$bidNo]["starline"] = $market_arr;

                        $game_info_query = "SELECT id, gameCode, gameName, win_point FROM starline_games WHERE id = :gameId";
                        $game_stmt = $this->conn->prepare($game_info_query);
                        $game_stmt->bindParam(":gameId", $bidRow["gameId"]);
                        $game_stmt->execute();
                        $game_arr = $game_stmt->fetch(PDO::FETCH_ASSOC);
                        $bid_arr[$bidNo]["game"] = $game_arr;
                    }
                    return $bid_arr;
                } else {
                    return [];
                }
            } else {
                return [];
            }
        } catch (Exception $e) {
            // print_r($e);
            return [];
        }
    }
}
