<?php
error_reporting(0);
class UserAuth
{
    // Connection
    private $conn;
    // Table
    private $db_table = "matka_user";
    // Columns
    public $id;
    public $name;
    public $email;
    public $mobile;
    public $password;
    public $createdOn;
    public $lastLogin;
    public $isBlocked;

    public $deviceId;
    public $deviceName;
    public $deviceToken;
    public $location;
    public $notifyMain;
    public $notifyMarket;
    public $notifyStarline;
    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    //Check User Exist Or Not On SignUp
    //Check email and mobile is exist or not
    public function userAlreadyExist()
    {
        $sqlQuery = "SELECT id FROM " . $this->db_table . " WHERE mobile = ?";
        $stmt = $this->conn->prepare($sqlQuery);
        $stmt->bindParam(1, $this->mobile);
        $stmt->execute();
        if ($stmt->rowCount() > 0) {
            return true;
        }
        return false;
    }

    public function userAlreadyExistFromId()
    {
        $sqlQuery = "SELECT id FROM " . $this->db_table . " WHERE id = ? AND isBlocked = 0";
        $stmt = $this->conn->prepare($sqlQuery);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();
        try {
            if ($stmt->rowCount() > 0) {
                return true;
            }
            return false;
        } catch (Exception $e) {
            return false;
            // print_r($e);
        }
    }

    // CREATE Account Using Phone
    public function createMatkaUser()
    {
        if ($this->userAlreadyExist() == true) {
            return false;
        }
        $sqlQuery = "INSERT INTO
                        " . $this->db_table . "
                    SET
                        name = :name, 
                        email = :email,
                        mobile = :mobile,
                        password = :password,
                        createdOn = :createdOn,
                        lastLogin = :lastLogin,
                        deviceId = :deviceId,
                        deviceName = :deviceName,
                        deviceToken = :deviceToken,
                        location = :location,
                        notifyMain = :notifyMain,
                        notifyMarket = :notifyMarket,
                        notifyStarline = :notifyStarline";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->name = htmlspecialchars(strip_tags($this->name));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->mobile = htmlspecialchars(strip_tags($this->mobile));
        $this->password = htmlspecialchars(strip_tags($this->password));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));
        $this->lastLogin = htmlspecialchars(strip_tags($this->lastLogin));
        $this->deviceId = htmlspecialchars(strip_tags($this->deviceId));
        $this->deviceName = htmlspecialchars(strip_tags($this->deviceName));
        $this->deviceToken = htmlspecialchars(strip_tags($this->deviceToken));
        $this->location = htmlspecialchars(strip_tags($this->location));
        $this->notifyMain = htmlspecialchars(strip_tags($this->notifyMain));
        $this->notifyMarket = htmlspecialchars(strip_tags($this->notifyMarket));
        $this->notifyStarline = htmlspecialchars(strip_tags($this->notifyStarline));

        // bind data
        $stmt->bindParam(":name", $this->name);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":mobile", $this->mobile);
        $stmt->bindParam(":password", $this->password);
        $stmt->bindParam(":createdOn", $this->createdOn);
        $stmt->bindParam(":lastLogin", $this->lastLogin);
        $stmt->bindParam(":deviceId", $this->deviceId);
        $stmt->bindParam(":deviceName", $this->deviceName);
        $stmt->bindParam(":deviceToken", $this->deviceToken);
        $stmt->bindParam(":location", $this->location);
        $stmt->bindParam(":notifyMain", $this->notifyMain);
        $stmt->bindParam(":notifyMarket", $this->notifyMarket);
        $stmt->bindParam(":notifyStarline", $this->notifyStarline);

        if ($stmt->execute()) {
            try {
                $this->id = $this->conn->lastInsertId();
            } catch (Exception $e) {
                // print_r($e);
            }
            return true;
        }
        return false;
    }

    public function userPasswordCheck()
    {
        $sqlQuery = "SELECT id, name, email, mobile, createdOn, lastLogin, isBlocked, deviceId, deviceName, deviceToken, location, notifyMain, notifyMarket, notifyStarline  FROM
                        " . $this->db_table . "
                    WHERE 
                        mobile = :mobile AND
                        password = :password
                    LIMIT 0,1";

        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->mobile = htmlspecialchars(strip_tags($this->mobile));
        //bind data
        $stmt->bindParam(":mobile", $this->mobile);
        $stmt->bindParam(":password", $this->password);

        $stmt->execute();
        return $stmt;
    }

    // public function updateLastLogin()
    // {
    //     if (isset($this->id) && $this->id != "") {
    //         $sqlQuery = "UPDATE
    //                             " . $this->db_table . "
    //                     SET
    //                         lastLogin = :lastLogin
    //                     WHERE 
    //                         id = :id";

    //         $stmt = $this->conn->prepare($sqlQuery);
    //         $newLastLogin = htmlspecialchars(strip_tags(date('Y-m-d H:i:s')));
    //         $this->id = htmlspecialchars(strip_tags($this->id));
    //         // bind data
    //         $stmt->bindParam(":lastLogin", $newLastLogin);
    //         $stmt->bindParam(":id", $this->id);
    //         if ($stmt->execute()) {
    //             return true;
    //         }
    //         return false;
    //     }
    // }

    // Get User Detail
    public function getUserDetail()
    {
        $sqlQuery = "SELECT id, name, email, mobile, createdOn, lastLogin, isBlocked, deviceId, deviceName, deviceToken, location, notifyMain, notifyMarket, notifyStarline FROM
                        " . $this->db_table . "
                    WHERE 
                        mobile = :mobile
                    LIMIT 0,1";
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        // $this->id = htmlspecialchars(strip_tags($this->id));
        $this->mobile = htmlspecialchars(strip_tags($this->mobile));
        //bind data
        // $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":mobile", $this->mobile);
        $stmt->execute();
        return $stmt;
    }

    public function updateUserDeviceDetail()
    {
        $sqlQuery = "UPDATE
                        " . $this->db_table . "
                    SET
                        deviceId = :deviceId, 
                        deviceName = :deviceName,
                        deviceToken = :deviceToken,
                        location = :location,
                        lastLogin = :lastLogin
                    WHERE 
                        id = :id";
        $stmt = $this->conn->prepare($sqlQuery);
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->deviceId = htmlspecialchars(strip_tags($this->deviceId));
        $this->deviceName = htmlspecialchars(strip_tags($this->deviceName));
        $this->deviceToken = htmlspecialchars(strip_tags($this->deviceToken));
        $this->location = htmlspecialchars(strip_tags($this->location));
        $this->lastLogin = htmlspecialchars(strip_tags($this->lastLogin));

        // bind data
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":deviceId", $this->deviceId);
        $stmt->bindParam(":deviceName", $this->deviceName);
        $stmt->bindParam(":deviceToken", $this->deviceToken);
        $stmt->bindParam(":location", $this->location);
        $stmt->bindParam(":lastLogin", $this->lastLogin);
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    public function updateUserAppSetting()
    {
        $sqlQuery = "UPDATE
                        " . $this->db_table . "
                    SET
                        notifyMain = :notifyMain, 
                        notifyMarket = :notifyMarket,
                        notifyStarline = :notifyStarline
                    WHERE 
                        id = :id";
        $stmt = $this->conn->prepare($sqlQuery);
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->notifyMain = htmlspecialchars(strip_tags($this->notifyMain));
        $this->notifyMarket = htmlspecialchars(strip_tags($this->notifyMarket));
        $this->notifyStarline = htmlspecialchars(strip_tags($this->notifyStarline));

        // bind data
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":notifyMain", $this->notifyMain);
        $stmt->bindParam(":notifyMarket", $this->notifyMarket);
        $stmt->bindParam(":notifyStarline", $this->notifyStarline);
        try {
            if ($stmt->execute()) {
                return true;
            }
        } catch (Exception $e) {
            print_r($e);
        }

        return false;
    }

    // UPDATE
    public function updateUser()
    {
        $sqlQuery = "UPDATE
                        " . $this->db_table . "
                    SET
                        name = :name, 
                        email = :email
                    WHERE 
                        id = :id";
        $stmt = $this->conn->prepare($sqlQuery);
        $this->name = htmlspecialchars(strip_tags($this->name));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->id = htmlspecialchars(strip_tags($this->id));
        // bind data
        $stmt->bindParam(":name", $this->name);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":id", $this->id);
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    //change password
    public function updatePassword()
    {
        $sqlQuery = "UPDATE
                        " . $this->db_table . "
                    SET
                        password = :password
                    WHERE 
                        mobile = :mobile";


        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->mobile = htmlspecialchars(strip_tags($this->mobile));
        //bind data
        $stmt->bindParam(":mobile", $this->mobile);
        $stmt->bindParam(":password", $this->password);

        if ($stmt->execute()) {
            return true;
        }
        return false;
    }
}
