<?php
error_reporting(0);
class Withdrawal
{
    // Connection
    private $conn;
    // Table
    private $db_table = "withdrawal";
    // Columns
    public $id;
    public $user_id;
    public $points;
    public $status;
    public $admin_id;
    public $method;
    public $method_id;
    public $createdOn;

    public $lastEntryId = 0;
    private $entriesLimit = 10;
    // Db connection
    public function __construct($db)
    {
        $this->conn = $db;
    }

    public function checkMethodExist(){
        $method_table = "bank_detail";
        $sqlQuery = "SELECT id FROM " . $method_table . " WHERE user_id = ? ORDER BY createdOn DESC, id LIMIT 0,1";
        $stmt = $this->conn->prepare($sqlQuery);
        $stmt->bindParam(1, $this->user_id);
        $stmt->execute();
        if ($stmt->rowCount() > 0) {
            $method_data = $stmt->fetch(PDO::FETCH_ASSOC);
            return $method_data["id"];
        }
        return 0;
    }

    public function checkWithdrawalRequest(){
        $cur_date = date_create();
        $cur_date = strval(date_format($cur_date, 'Y-m-d'));
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE user_id = :user_id AND DATE(createdOn) = :cur_date";
                    $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        //bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":cur_date", $cur_date);
        $stmt->execute();
        if ($stmt->rowCount() > 0) {
           return true;
        }else{
            return false;
        }
    }

    public function sendWithdrawalRequest(){
        $sqlQuery = "INSERT INTO
                        " . $this->db_table . "
                    SET
                        user_id = :user_id,
                        points = :points,
                        status = :status,
                        admin_id = :admin_id,
                        method = :method,
                        method_id = :method_id,
                        createdOn = :createdOn";

        $stmt = $this->conn->prepare($sqlQuery);

        // sanitize
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        $this->points = htmlspecialchars(strip_tags($this->points));
        $this->status = htmlspecialchars(strip_tags($this->status));
        $this->admin_id = htmlspecialchars(strip_tags($this->admin_id));
        $this->method = htmlspecialchars(strip_tags($this->method));
        $this->method_id = htmlspecialchars(strip_tags($this->method_id));
        $this->createdOn = htmlspecialchars(strip_tags($this->createdOn));
        // bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":points", $this->points);
        $stmt->bindParam(":status", $this->status);
        $stmt->bindParam(":admin_id", $this->admin_id);
        $stmt->bindParam(":method", $this->method);
        $stmt->bindParam(":method_id", $this->method_id);
        $stmt->bindParam(":createdOn", $this->createdOn);

        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    public function getWithdrawalHistory(){
        $querySymbol = $this->lastEntryId == 0 ? ">" : "<";
        $sqlQuery = "SELECT * FROM
                        " . $this->db_table . "
                    WHERE 
                        user_id = :user_id && id ". $querySymbol ." :last_entry_id ORDER BY createdOn DESC, id DESC LIMIT ".$this->entriesLimit;
        $stmt = $this->conn->prepare($sqlQuery);
        //Filter Data
        $this->user_id = htmlspecialchars(strip_tags($this->user_id));
        $this->lastEntryId = htmlspecialchars(strip_tags($this->lastEntryId));
        //bind data
        $stmt->bindParam(":user_id", $this->user_id);
        $stmt->bindParam(":last_entry_id", $this->lastEntryId);
        $stmt->execute();
        return $stmt;
    }
}
